Bifrost: src/Kmer.hpp File Reference

Bifrost

Data Structures
Kmer.hpp File Reference

Interface for the class Kmer: More...

Go to the source code of this file.

## Data Structures
class | Kmer
| Interface to store and manipulate k-mers. More...
struct | KmerHash

## Detailed Description

Interface for the class Kmer:

- Store k-mer strings by using 2 bits per base
- Easily return reverse-complements of k-mers, e.g. TTGG -> CCAA
- Easily compare k-mers
- Provide hash of k-mers
- Get last and next kmer, e.g. ACGT -> CGTT or ACGT -> AACGT